<?php

function theme_init_theme() {
	# Enqueue jQuery
	wp_enqueue_script('jquery');
	
	# Enqueue Custom Scripts & Styles
	if (!is_admin()) {
		wp_enqueue_script('jquery-dual-slider', get_bloginfo('stylesheet_directory') . '/js/dual-slider.js', array('jquery'), '1.0');
		wp_enqueue_script('jquery-easing', get_bloginfo('stylesheet_directory') . '/js/jquery.easing.1.3.js', array('jquery'), '1.3');
		wp_enqueue_script('jquery-timers', get_bloginfo('stylesheet_directory') . '/js/jquery.timers-1.2.js', array('jquery'), '1.2');
		wp_enqueue_script('jquery-jqtransform', get_bloginfo('stylesheet_directory') . '/js/jquery.jqtransform.js', array('jquery'), '1.1');
		wp_enqueue_script('jquery-theme-custom', get_bloginfo('stylesheet_directory') . '/js/functions.js', array('jquery', 'jquery-easing', 'jquery-timers', 'jquery-jqtransform'), '1.0');

		wp_enqueue_style('jquery-dual-slider', get_bloginfo('stylesheet_directory') . '/dual-slider.css', array(), '1.0');
		wp_enqueue_style('jquery-jqtransform', get_bloginfo('stylesheet_directory') . '/jqtransform.css', array(), '1.1');
		wp_enqueue_style('google-font-cabin', 'http://fonts.googleapis.com/css?family=Cabin:500,600,700,700italic,600italic,500italic,400italic,400');
	}
	
}
add_action('init', 'theme_init_theme');


add_action('after_setup_theme', 'theme_setup_theme');

# To override theme setup process in a child theme, add your own theme_setup_theme() to your child theme's
# functions.php file.
if ( ! function_exists( 'theme_setup_theme' ) ):
function theme_setup_theme() {
	include_once('lib/common.php');

	# Theme supports
	add_theme_support('automatic-feed-links');
	add_theme_support('menus');
	add_theme_support('post-thumbnails');

	# Custom image sizes
	add_image_size('post_thumb', 225, 225, true);
	
	# Manually select Post Formats to be supported - http://codex.wordpress.org/Post_Formats
	// add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio', 'chat' ) );

	# Register Theme Menu Locations
	register_nav_menus(array(
		'main-menu'=>__('Main Menu'),
	));

	# Register CPTs
	include_once('options/theme-post-types.php');
	
	# Attach custom widgets
	include_once('lib/custom-widgets/widgets.php');
	include_once('options/theme-widgets.php');
	
	# Add Actions
	add_action('widgets_init', 'theme_widgets_init');
	add_action('wp_loaded', 'attach_theme_options');
	add_action('wp_head', '_print_ie6_styles');

	# Add Filters
	add_filter('widget_text', 'do_shortcode');	
}
endif;

# Register Sidebars
# Note: In a child theme with custom theme_setup_theme() this function is not hooked to widgets_init
function theme_widgets_init() {
	register_sidebar(array(
	    'id'=>'posts-sidebar',
	    'name'=>'Posts Sidebar',
        'before_widget' => '<div id="%1$s" class="widget s-widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="widgettitle">',
        'after_title' => '</h4>',
	));
	register_sidebar(array(
		'name' => 'Home Widgets',
		'id' => 'home-widgets',
		'before_widget' => '<div id="%1$s" class="left widget s-widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle">',
		'after_title' => '</h4>',
	));
	for($i = 1; $i <= 5; $i++) {
		register_sidebar(array(
			'name' => 'Footer Sitemap Column ' . $i,
			'id' => 'footer-sitemap-' . $i,
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widgettitle">',
			'after_title' => '</h4>',
		));
	}
}

function attach_theme_options() {
	# Attach theme options
	include_once('lib/theme-options/theme-options.php');
	
	include_once('options/theme-options.php');
	// include_once('options/other-options.php');
	
	# Theme Help needs to be after options/theme-options.php
	include_once('lib/theme-options/theme-readme.php');
	
	# Attach ECFs
	include_once('lib/enhanced-custom-fields/enhanced-custom-fields.php');
	include_once('options/theme-custom-fields.php');

	# Include shortcodes
	include_once('options/theme-shortcodes.php');
}

/* Custom code goes below this line. */

add_filter('excerpt_length', 'sts_excerpt_length');
function sts_excerpt_length($length) {
	return 18;
}

add_filter('excerpt_more', 'sts_excerpt_more');
function sts_excerpt_more($more) {
	global $post;
	return ' <a href="' . get_permalink() . '">more</a>';
}

function sts_excerpt_length_large($length) {
	return 56;
}

function sts_excerpt_more_blog($more) {
	return '...';
}

add_filter('widget_title', 'sts_widget_title');
function sts_widget_title($title) {
	if (trim($title)) {
		$page = get_page_by_path(sanitize_title_with_dashes($title));
		if ($page) {
			$title = '<a href="' . get_permalink($page->ID) . '">' . $title . '</a>';
		} else {
			$cat = get_term_by('slug', sanitize_title_with_dashes($title), 'category');
			if ($cat) {
				$title = '<a href="' . get_category_link($cat->term_id) . '">' . $title . '</a>';
			}
		}
	}
	return $title;
}

/* Custom code goes above this line. */
?>