<?php
/*
* Register the new widget classes here so that they show up in the widget list
*/
function load_widgets() {
	register_widget('LatestTweets');
	register_widget('ThemeWidgetVideo');
	register_widget('ThemeWidgetLatestNews');
	register_widget('ThemeWidgetFacebookFanBox');
	register_widget('ThemeWidgetTwitterBox');
}
add_action('widgets_init', 'load_widgets');

/*
* Displays a block with latest tweets from particular user
*/
class LatestTweets extends ThemeWidgetBase {
	function LatestTweets() {
		$widget_opts = array(
			'classname' => 'theme-widget',
			'description' => 'Displays a block with your latest tweets'
		);
		$this->WP_Widget('theme-widget-latest-tweets', 'Latest Tweets', $widget_opts);
		$this->custom_fields = array(
			array(
				'name'=>'title',
				'type'=>'text',
				'title'=>'Title',
				'default'=>''
			),
			array(
				'name'=>'username',
				'type'=>'text',
				'title'=>'Username',
				'default'=>''
			),
			array(
				'name'=>'count',
				'type'=>'text',
				'title'=>'Number of Tweets to show',
				'default'=>'5'
			),
		);
	}
	
	/*
	* Called when rendering the widget in the front-end
	*/
	function front_end($args, $instance) {
		extract($args);
		$tweets = TwitterHelper::get_tweets($instance['username'], $instance['count']);
		if (!empty($tweets)) {
			if ($instance['title'])
				echo $before_title . $instance['title'] . $after_title;
		}
		?>
		<ul>
			<?php foreach ($tweets as $tweet): ?>
				<li><?php echo $tweet->tweet_text ?> - <span><?php echo $tweet->time_distance ?> ago</span></li>
			<?php endforeach ?>
		</ul>
		<?php
	}
}

class ThemeWidgetVideo extends ThemeWidgetBase {
	function ThemeWidgetVideo() {
		$widget_opts = array(
			'classname' => 'theme-widget',
			'description' => __( 'Displays a widget with title, video and description.' )
		);
		$control_ops = array();
		$this->WP_Widget('theme-widget-video', 'Video Widget', $widget_opts, $control_ops);
		$this->custom_fields = array(
			array(
				'name'=>'title',
				'type'=>'text',
				'title'=>'Title',
				'default'=>'Widget Title'
			),
			array(
				'name'=>'video_url',
				'type'=>'text',
				'title'=>'Video URL', 
				'default'=>''
			),
			array(
				'name'=>'text',
				'type'=>'textarea',
				'title'=>'Description', 
				'default'=>''
			),
		);
	}
	function front_end($args, $instance) {
		if ($instance['title']): ?>
			<h4><?php echo $instance['title']; ?></h4>
		<?php endif;
		if ($instance['video_url']) {
			echo '<div class="vid">';
			echo create_embedcode($instance['video_url'], 289, 176);
			echo '</div>';
		}
		echo wpautop($instance['text']);
	}
}

class ThemeWidgetLatestNews extends ThemeWidgetBase {
	function ThemeWidgetLatestNews() {
		$widget_opts = array(
			'classname' => 'theme-widget latest',
			'description' => __( 'Displays most recent news entries.' )
		);
		$control_ops = array();
		$this->WP_Widget('theme-widget-latest-news', 'Latest News', $widget_opts, $control_ops);
		$this->custom_fields = array(
			array(
				'name'=>'title',
				'type'=>'text',
				'title'=>'Title',
				'default'=>'Latest News'
			),
			array(
				'name'=>'count',
				'type'=>'integer',
				'title'=>'Number of entries', 
				'default'=>3
			),
		);
	}
	function front_end($args, $instance) {
		$count = intval($instance['count']);
		if (!$count) {
			$count = 3;
		}
		$cat = get_term_by('slug', 'news', 'category');
		?>
    	<div class="latest-bottom">
    		<div class="latest-cnt">
    			<?php if ($instance['title']): ?>
    				<h3><img src="<?php bloginfo('stylesheet_directory'); ?>/images/news-heading.png" alt="image" /><?php echo $instance['title']; ?></h3>
    			<?php endif ?>
    			<?php query_posts('post_type=post&posts_per_page=' . $count . '&cat=' . $cat->term_id); ?>
    			<?php while(have_posts()): the_post(); ?>
	    			<div class="article">
	    				<h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
	    				<div class="inner-txt">
	    					<?php the_excerpt(); ?>
	    				</div>
	    			</div>
    			<?php endwhile; ?>
    			<?php wp_reset_query(); ?>
    		</div>
    	</div>
		<?php
	}
}

class ThemeWidgetFacebookFanBox extends ThemeWidgetBase {
	function ThemeWidgetFacebookFanBox() {
		$widget_opts = array(
			'classname' => 'theme-widget facebook-widget',
			'description' => __( 'Displays a facebook fan box. Uses the URL of the Facebook Link option.' )
		);
		$control_ops = array();
		$this->WP_Widget('theme-widget-facebook-box', 'Facebook Box', $widget_opts, $control_ops);
		$this->custom_fields = array();
	}
	function front_end($args, $instance) {
		?>
		 <div class="facebook"><iframe src="http://www.facebook.com/plugins/likebox.php?href=<?php echo urlencode(get_option('facebook_link')); ?>&amp;width=300&amp;height=258&amp;colorscheme=light&amp;show_faces=true&amp;border_color&amp;stream=false&amp;header=false" scrolling="no" frameborder="0" style="border:none; background:#fff; overflow:hidden; width:300px; height:258px;" allowTransparency="true"></iframe></div>
		<?php
	}
}

class ThemeWidgetTwitterBox extends ThemeWidgetBase {
	function ThemeWidgetTwitterBox() {
		$widget_opts = array(
			'classname' => 'theme-widget twitter-widget',
			'description' => __( 'Displays a twitter latest tweet box. Fully customizable. Go to http://twitter.com/about/resources/widgets/widget_list to create your widget code.' )
		);
		$control_ops = array();
		$this->WP_Widget('theme-widget-twitter-box', 'Twitter Box', $widget_opts, $control_ops);
		$this->custom_fields = array(
			array(
				'name'=>'code',
				'type'=>'textarea',
				'title'=>'Code',
				'default'=>''
			),
		);
	}
	function front_end($args, $instance) {
		echo $instance['code'];
	}
}
?>